/* Integrating DJ Native Swing into NetBeans RCP
 *
 * See the DJ Project by Christopher Deckers
 * http://djproject.sourceforge.net/ns/index.html
 *
 * Geertjaan Wielenga "Step-by-Step Instructions for Integrating DJ Native
 * Swing into NetBeans RCP"
 * http://netbeans.dzone.com/how-to-nb-djnative-swing?utm_source=feedburner&utm_
 * medium=feed&utm_campaign=Feed%3A+zones%2Fnetbeans+%28NetBeans+Zone%29
 *
 * Eclipse swt library
 * http://download.eclipse.org/eclipse/downloads/drops/R-3.6-201006080911/
 *
 * This code may be freely distributed and modified under the
 * terms of the GNU Lesser General Public Licence v2.1.
 */

package org.starbeans.api.nativeswing;

import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import org.openide.modules.ModuleInstall;
import org.starbeans.api.nativeswing.utils.ModuleHandler;

/**
 * Manages a module's lifecycle. Remember that an installer is optional and
 * often not needed at all.
 */
public class Installer extends ModuleInstall {

    @Override
    public void restored() {

        Map<String,String> modelMap = new HashMap<String,String>();
        modelMap.put("Windows.64", "org.starbeans.libs.nativeswing.windows64");
        modelMap.put("Linux.64", "org.starbeans.libs.nativeswing.linux64");

        String osArch = System.getProperty("os.arch");
        if ("amd64".equals(osArch)) {
            osArch = "64";
        } else {
            osArch = "32";
        }

        String osName = System.getProperty("os.name");
        if (osName.startsWith("Windows")) {
            osName = "Windows";
        }
        if (osName.startsWith("Mac")) {
            osName = "Mac";
        }

        Map osNameMap = new HashMap();
        osNameMap.put("Windows", "Windows");
        osNameMap.put("Linux", "Linux");
        osNameMap.put("Mac", "Mac");

        String toEnable = modelMap.get(osNameMap.get(osName) + "." + osArch);
        Set toDisable = new HashSet(modelMap.values());
        if (toEnable != null) {
            toDisable.remove(toEnable);
        }

        ModuleHandler disabler = new ModuleHandler(true);
        disabler.setModulesState(false, toDisable);

        ModuleHandler enabler = new ModuleHandler(true);
        enabler.setModulesState(true, Collections.singleton(toEnable));

    }

}