/*
 * @author George Waldon
 *
 * This code may be freely distributed and modified under the
 * terms of the GNU Lesser General Public Licence v2.1.
 */

package org.starbeans.api.nativeswing.browser;

import java.awt.BorderLayout;
import java.awt.Image;
import java.net.URL;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.Mode;
import org.openide.windows.TopComponent;
import org.openide.windows.WindowManager;

public class BrowserWindow extends TopComponent {

     private static final String PREFERRED_ID = "swtbrowser"; //NOI18N

    /** Show a URL in an swt browser window.
     *
     * @param url The url to reach.
     * @param title The title of the TopComponent.
     * @param icon The icon to display in the title bar.
     * @return true if a BrowserProvider has been found to display the url, otherwise false.
     */
    public static boolean ShowBrowserWindow(URL url, String title, Image icon) {
        WindowManager wm = WindowManager.getDefault();
        Mode mode = wm.findMode("editor"); //NOI18N
        if (mode == null) {
            //See doc, editor mode should always exists.
            return false;
        }
        BrowserProvider bp = Lookup.getDefault().lookup(BrowserProvider.class);
        if (bp != null) {
            BrowserWindow bw = new BrowserWindow(url,title,icon);
            bw.open();
            bw.requestActive();
            return true;
        }
        return false;
    }

    public static boolean ShowBrowserWindow(URL url) {
        return ShowBrowserWindow(url,null,null);
    }

    public BrowserWindow(URL url, String title, Image icon){
        setLayout(new BorderLayout());
        String name = (title!=null && !title.isEmpty())? title : NbBundle.getMessage(BrowserWindow.class, "LBL_swtbrowser");
        setName(name);
        Image img = icon;
        if(img==null)
            img = ImageUtilities.loadImage("org/starbeans/api/nativeswing/resources/webicon.png"); //NOI18N
        setIcon(img);
        BrowserProvider bp = Lookup.getDefault().lookup(BrowserProvider.class);
        if (bp != null) {
            Browser createBrowser = bp.createBrowser();
            add(createBrowser.getBrowserComponent(), BorderLayout.CENTER);
            if(url!=null)
                createBrowser.browseTo(url);
        }
        
    }

    @Override
    protected String preferredID() {
        return PREFERRED_ID;
    }

    @Override
    public int getPersistenceType() {
        return TopComponent.PERSISTENCE_NEVER;
    }
}
